__title__ = "cfgdict"
__description__ = "A lightweight dict-like config library with validation support"
__url__ ='http://github.com/gseismic/cfgdict',
__version__ = "1.0.5"
__author__ = "Liu Shengli"
__license__ = "MIT"
